@@ -36,11 +36,18 @@ def _validate_event_desc(ctx, param, event_file):
     if event_file is None:
         return None
     try:
-        event_desc = json.load(event_file)
+        events_desc = json.load(event_file)
     except (TypeError, ValueError):
         logger.error("Can't parse event description file %s", event_file)
     else:
-        return event_desc
+        events = []
+        event_type = type(events_desc)
+
+        if event_type is list:
+            events.extend(events_desc)
+        else:
+            events.append(events_desc)
+        return events
 
 
 def _read_powny_api_url_from_settings(ctx, param, api_url):
@@ -55,9 +62,19 @@ def _read_powny_api_url_from_settings(ctx, param, api_url):
 
 def _get_event_from_args(event_args):
     if event_args and len(event_args) == 3:
-        return {'host': event_args[0], 'service': event_args[1], 'status': event_args[2]}
+        events = []
+        event_base = {'host': event_args[0], 'service': event_args[1]}
+
+        if ':' in event_args[2]:
+            for status in event_args[2].split(':'):
+                event_base.update({'status': status})
+                events.append(event_base.copy())
+        else:
+            event_base.update({'status': event_args[2]})
+            events.append(event_base.copy())
+        return events
     else:
-        raise click.BadParameter("You mast pass `host service status` args or `--file` option")
+        raise click.BadParameter("You mast pass `host service status[:new status]` args or `--file` option")
 
 
 @click.group()
@@ -66,6 +83,7 @@ def _get_event_from_args(event_args):
               callback=_validate_repo_path, default=gitapi.get_root(fallback="."), help="Path to rules dir")
 @click.option('--config', '-c', callback=Settings.load, type=click.File('r'),
               help="Load config from file", metavar='PATH')
+@click.version_option()
 def cli(debug, work_dir, config):
     """
     Powny command line tool.
@@ -112,6 +130,7 @@ def open_log_page(browser):
     Open kibana logs dashboard in browser.
     """
     url = Settings.get("kibana_dashboard_url")
+    click.echo("Try to open {}".format(url))
 
     try:
         if browser:
@@ -156,10 +175,10 @@ def execute(event_desc, event_args):
     """
     Run Powny rules locally.
     """
-    event = event_desc or _get_event_from_args(event_args)
+    events = event_desc or _get_event_from_args(event_args)
 
     config = Settings.config
-    checker.check(config, Settings.get('rules_path'), event)
+    checker.check(config, events)
 
 
 @cli.group()
@@ -253,10 +272,11 @@ def send_event(event_args, file):
     Could be called with arguments `host service status` or with JSON file event description.
     """
 
-    event = file or _get_event_from_args(event_args)
+    events = file or _get_event_from_args(event_args)
 
-    logger.info("Send event: {}".format(event))
-    pownyapi.send_event(Settings.get('powny_api_url'), event)
+    for event in events:
+        logger.info("Send event: {}".format(event))
+        pownyapi.send_event(Settings.get('powny_api_url'), event)
 
 
 def main():
